@@ -15,7 +15,8 @@ class ProfileTestCase( unittest.TestCase ):
                             filename="profile_test.log")
         thisdir = dirname(abspath(getsourcefile(lambda:0)))
         self.configdatadir = join(thisdir,'config')
-        config_file = os.path.join(self.configdatadir,'channelprofiles.xml')
+        config_file = os.path.join(self.configdatadir,
+                                   'channelprofiles.xml')
         parser = lxml.etree.XMLParser(remove_blank_text=True)
         configuration_data =  lxml.etree.parse(config_file, parser)
         self.handler = ChannelProfileHandler(configuration_data)
@@ -214,7 +215,7 @@ class ProfileTestCase( unittest.TestCase ):
         self._test_regression('0005', result, expected)
 
 
-
+    #@unittest.skip('Fix later')
     def test_0006(self):
         logging.info('Test 0006')
         data = etree.fromstring("""<?xml version="1.0" encoding="UTF-8"?>
@@ -239,10 +240,9 @@ class ProfileTestCase( unittest.TestCase ):
         result = self.handler.apply_profile_configs(data)
         logging.info('Result: {}'.format(lxml.etree.tostring(result,
                                                              pretty_print=True)))
-        expected = etree.fromstring("""<?xml version="1.0" encoding="UTF-8"?>
-        <cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
-        <cppa:ebMS3Channel package="entsog_package" includeAgreementRef="false">
-    <cppa:Description xml:lang="en">Channel for outgoing ENTSOG AS4 User Messages</cppa:Description>
+        expected = etree.fromstring("""<cppa:CPP xmlns:cppa="http://docs.oasis-open.org/ebcore/ns/cppa/v3.0">
+  <cppa:ebMS3Channel package="entsog_package" includeAgreementRef="false">
+    <cppa:Description xml:lang="en">Channel for any ENTSOG AS4 User Messages</cppa:Description>
     <cppa:ChannelProfile>http://www.entsog.eu/publications/as4#AS4-USAGE-PROFILE/v2.0/UserMessageChannel</cppa:ChannelProfile>
     <cppa:SOAPVersion>1.2</cppa:SOAPVersion>
     <cppa:WSSecurityBinding>
@@ -276,11 +276,10 @@ class ProfileTestCase( unittest.TestCase ):
     </cppa:AS4ReceptionAwareness>
     <cppa:ErrorHandling>
       <cppa:DeliveryFailuresNotifyProducer>true</cppa:DeliveryFailuresNotifyProducer>
-      <cppa:SenderErrorsReportChannelId>incoming_sync_signal_channel</cppa:SenderErrorsReportChannelId>
     </cppa:ErrorHandling>
-    <cppa:ReceiptHandling>
-      <cppa:ReceiptChannelId>incoming_sync_signal_channel</cppa:ReceiptChannelId>
-    </cppa:ReceiptHandling>
+    <cppa:Compression>
+      <cppa:CompressionAlgorithm>application/gzip</cppa:CompressionAlgorithm>
+    </cppa:Compression>
   </cppa:ebMS3Channel>
 </cppa:CPP>
 """, self.parser)
@@ -301,26 +300,12 @@ class ProfileTestCase( unittest.TestCase ):
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
     <cppa:ErrorHandling>
-      <cppa:SenderErrorsReportChannelId>ougoing_sync_signal_channel</cppa:SenderErrorsReportChannelId>
     </cppa:ErrorHandling>
     <cppa:ReceiptHandling>
-      <cppa:ReceiptChannelId>ougoing_sync_signal_channel</cppa:ReceiptChannelId>
-    </cppa:ReceiptHandling>
-  </cppa:ebMS3Channel>
-  <cppa:ebMS3Channel id="ch_receive" transport="tr_receive" package="entsog_package">
-    <cppa:Description xml:lang="en">Channel for incoming ENTSOG AS4 User Messages</cppa:Description>
-    <cppa:ChannelProfile>http://www.entsog.eu/publications/as4#AS4-USAGE-PROFILE/v2.0/UserMessageChannel</cppa:ChannelProfile>
-    <cppa:WSSecurityBinding>
-      <cppa:Encryption>
-        <cppa:EncryptionCertificateRef certId="_YE5XZF"/>
-      </cppa:Encryption>
-    </cppa:WSSecurityBinding>
-    <cppa:ErrorHandling>
-      <cppa:SenderErrorsReportChannelId>ougoing_sync_signal_channel</cppa:SenderErrorsReportChannelId>
-    </cppa:ErrorHandling>
-    <cppa:ReceiptHandling>
-      <cppa:ReceiptChannelId>ougoing_sync_signal_channel</cppa:ReceiptChannelId>
     </cppa:ReceiptHandling>
+    <cppa:Compression>
+      <cppa:CompressionAlgorithm>application/gzip</cppa:CompressionAlgorithm>
+    </cppa:Compression>
   </cppa:ebMS3Channel>
 </cppa:CPP>""", self.parser)
         result = self.handler.apply_profile_configs(data)
@@ -361,51 +346,12 @@ class ProfileTestCase( unittest.TestCase ):
     </cppa:AS4ReceptionAwareness>
     <cppa:ErrorHandling>
       <cppa:DeliveryFailuresNotifyProducer>true</cppa:DeliveryFailuresNotifyProducer>
-      <cppa:SenderErrorsReportChannelId>ougoing_sync_signal_channel</cppa:SenderErrorsReportChannelId>
     </cppa:ErrorHandling>
     <cppa:ReceiptHandling>
-      <cppa:ReceiptChannelId>ougoing_sync_signal_channel</cppa:ReceiptChannelId>
-    </cppa:ReceiptHandling>
-  </cppa:ebMS3Channel>
-  <cppa:ebMS3Channel id="ch_receive" transport="tr_receive" package="entsog_package" includeAgreementRef="false">
-    <cppa:Description xml:lang="en">Channel for incoming ENTSOG AS4 User Messages</cppa:Description>
-    <cppa:ChannelProfile>http://www.entsog.eu/publications/as4#AS4-USAGE-PROFILE/v2.0/UserMessageChannel</cppa:ChannelProfile>
-    <cppa:SOAPVersion>1.2</cppa:SOAPVersion>
-    <cppa:WSSecurityBinding>
-      <cppa:WSSVersion>1.1</cppa:WSSVersion>
-      <cppa:Signature>
-        <cppa:SignatureAlgorithm>https://www.w3.org/2001/04/xmldsig-more#rsa-sha256</cppa:SignatureAlgorithm>
-        <cppa:DigestAlgorithm>http://www.w3.org/2001/04/xmlenc#sha256</cppa:DigestAlgorithm>
-      </cppa:Signature>
-      <cppa:Encryption>
-        <cppa:KeyEncryption>
-          <cppa:EncryptionAlgorithm> http://www.w3.org/2009/xmlenc11#rsa-oaep</cppa:EncryptionAlgorithm>
-          <cppa:MaskGenerationFunction>http://www.w3.org/2009/xmlenc11#mgf1sha256</cppa:MaskGenerationFunction>
-          <cppa:DigestAlgorithm>http://www.w3.org/2001/04/xmlenc#sha256</cppa:DigestAlgorithm>
-        </cppa:KeyEncryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
-        <cppa:EncryptionCertificateRef certId="_YE5XZF"/>
-      </cppa:Encryption>
-    </cppa:WSSecurityBinding>
-    <cppa:AS4ReceptionAwareness>
-      <cppa:DuplicateHandling>
-        <cppa:DuplicateElimination>true</cppa:DuplicateElimination>
-        <cppa:PersistDuration>P10D</cppa:PersistDuration>
-      </cppa:DuplicateHandling>
-      <cppa:RetryHandling>
-        <cppa:Retries>5</cppa:Retries>
-        <cppa:RetryInterval>PT30S</cppa:RetryInterval>
-      </cppa:RetryHandling>
-    </cppa:AS4ReceptionAwareness>
-    <cppa:ErrorHandling>
-      <cppa:DeliveryFailuresNotifyProducer>true</cppa:DeliveryFailuresNotifyProducer>
-      <cppa:SenderErrorsReportChannelId>ougoing_sync_signal_channel</cppa:SenderErrorsReportChannelId>
-    </cppa:ErrorHandling>
-    <cppa:ReceiptHandling>
-      <cppa:ReceiptChannelId>ougoing_sync_signal_channel</cppa:ReceiptChannelId>
     </cppa:ReceiptHandling>
+    <cppa:Compression>
+      <cppa:CompressionAlgorithm>application/gzip</cppa:CompressionAlgorithm>
+    </cppa:Compression>
   </cppa:ebMS3Channel>
 </cppa:CPP>
 """, self.parser)
