@@ -275,6 +275,42 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_0061(self):
         self.do_unification('0061')
 
+    # IPv4 and IPv6 compatibility
+    # A is IPv4 only,  B is any
+    def test_0070(self):
+        self.do_unification('0070')
+
+    # B is IPv4 only,  A is any
+    def test_0071(self):
+        self.do_unification('0071')
+
+    # A is IPv4 only,  B is IPv6 only
+    def test_0072(self):
+        self.assertRaises( cppa3.unify.UnificationException, self.do_unification, '0072' )
+
+
+    # HTTP version support.
+    # B can support 1.1 and 2.0 A only 1.1
+    def test_0080(self):
+        self.do_unification('0080')
+
+    # Both can support 1.1 and 2.0
+    def test_0081(self):
+        self.do_unification('0081')
+
+    # HTTP Content Encoding
+    def test_0083(self):
+        self.do_unification('0083')
+
+    def test_0084(self):
+        self.do_unification('0084')
+
+    # HTTP Chunking
+    def test_0085(self):
+        self.do_unification('0085')
+
+
+
     """
     Payload Profile
     """
@@ -863,11 +899,30 @@ class CPPA3TestCase( unittest.TestCase ):
 
     # Scope ?
 
-    # @@@ TO DO:  Split / Join / Compress
+    # Split / Join / Compress
+    def test_1550(self):
+        # Base case
+        self.do_unification('1550')
 
-    # 1600 ENTSOG AS4 tests
+    def test_1555(self):
+        # Compression on both sides,  compatible
+        self.do_unification('1555')
 
-    # Not using ChannelProfile defaults
+    def test_1556(self):
+        # FragmentSize
+        self.do_unification('1556')
+
+    def test_1557(self):
+        # Properties
+        self.do_unification('1557')
+
+    def test_1558(self):
+        # Properties, this time reusing a PropertySet
+        self.do_unification('1558')
+
+    # 1600 Various AS4 tests
+
+    # ENTSOG AS4 Not using ChannelProfile defaults
     def test_1600(self):
         self.do_unification('1600')
 
@@ -889,6 +944,13 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_1604(self):
         self.do_unification('1604', handle_defaults=True)
 
+    # Client Certificate,  referenced from transport
+    def test_1610(self):
+        self.do_unification('1610', handle_defaults=True)
+
+    # Client Certificate,  set as default
+    def test_1611(self):
+        self.do_unification('1611', handle_defaults=True)
 
     # 1900 SAML Conformance Clause
 
@@ -916,6 +978,11 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_1905(self):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '1905')
 
+    # 1900, A and B swapped
+    def test_1906(self):
+        self.do_unification('1906')
+
+
     """
     Web Services Tests
     """
@@ -1063,6 +1130,17 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_2202(self):
         self.do_unification('2200')
 
+    # WS Reliable Messaging
+    # Base case, Protocol selection
+    def test_2300(self):
+        self.do_unification('2300')
+
+    # Ack on Receipt
+    def test_2303(self):
+        self.do_unification('2303')
+
+    def test_2304(self):
+        self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '2304')
 
 
     # Packaging
